@@ -1,4 +1,5 @@
 globalVariables(c(".", "identifier", "term_nr", "term", "statistic", "value", "median", "sd", "SD",
                   "Df", "Sum Sq", "pf", "Mean Sq", "F value", "logLik", "Chisq", "Chi Df", "Res.Df",
                   "Pr(>Chisq)", "Estimate", "Std. Error", "t value", "Pr(>|t|)", "Sum of Sq",
-                  "Pr(>F)", "pct_group"))
\ No newline at end of file
+                  "Pr(>F)", "pct_group", "method", "confirmatory", "notes", "var", "group", "CI",
+                  "b", "SE", "df", "p", "*term*"))
\ No newline at end of file
